var width = 290,
    height = 210,
    radius = Math.min(width, height) / 2,
    color = d3.scale.category20c();

var svg = d3.select("svg#chart")
    .attr("width", width)
    .attr("height", height)
    .append("g")
    .attr("transform", "translate(" + width / 2 + "," + height / 2 + ")");

var partition = d3.layout.partition()
    .sort(null)
    .size([2 * Math.PI, radius * radius])
    .value(function(d) { return 1; });

var arc = d3.svg.arc()
    .startAngle(function(d) { return d.x; })
    .endAngle(function(d) { return d.x + d.dx; })
    .innerRadius(function(d) { return Math.sqrt(d.y); })
    .outerRadius(function(d) { return Math.sqrt(d.y + d.dy); });

function draw(json) {
    var path = svg.datum(json).selectAll("path")
        .data(partition.nodes)
        .enter().append("path")
        .attr("display", function(d) { return d.depth ? null : "none"; }) // hide inner ring
        .attr("d", arc)
        .style("stroke", "#fff")
        .style("fill", function(d) { return color((d.children ? d : d.parent).name); })
        .style("fill-rule", "evenodd")
        .each(stash)
        .on('mouseover', function(d){ $("strong#legend").text(d.name)});

    /* d3.selectAll("input").on("change", function change() {
        var value = this.value === "count"
            ? function() { return 1; }
            : function(d) { return d.size; };

        path
            .data(partition.value(value).nodes)
            .transition()
            .duration(1500)
            .attrTween("d", arcTween);
    }); */
}

// Stash the old values for transition.
function stash(d) {
    d.x0 = d.x;
    d.dx0 = d.dx;
}

// Interpolate the arcs in data space.
function arcTween(a) {
    var i = d3.interpolate({x: a.x0, dx: a.dx0}, a);
    return function(t) {
        var b = i(t);
        a.x0 = b.x;
        a.dx0 = b.dx;
        return arc(b);
    };
}

function getJSON(element, curLevel, maxLevel) {
    var result = {
        name: "tei:" + element.tagName
    };

    if (curLevel < maxLevel && $(element).children().length > 0) {
        var children = [];

        $(element).children().each(function() {
            children.push(getJSON(this, curLevel + 1, maxLevel));
        });

        result["children"] = children;
        return result;
    } else {
        var size = 0;

        $(element).find("*").each(function() {
            size += $(this).text().length;
        });

        /* var size = $(element).find("*").length; */

        result["size"] = size;
        return result;
    }
};

$.ajax({
    type: "GET",
    url: "/exist/rest/db/sade-projects/textgrid/data/xml/data/24ds1.0.xml?_xsl=no"
}).done(function(data) {
    draw(getJSON($(data).find("TEI", "tei\\:TEI")[0], 1, 5));
});
